@@ -15,15 +15,13 @@ use File::Temp qw(tempdir);
 use Getopt::Std;
 use Log::Log4perl;
 
-$VERSION = '1.19';
+$VERSION = '1.21';
 
 $|++;
 
 my $logger = Log::Log4perl->get_logger( 'backpan_indexer' );
 
-__PACKAGE__->run( @ARGV ) unless caller;
-
-#$SIG{__WARN__} = sub { Carp::cluck( @_ ) };
+__PACKAGE__->activate( @ARGV ) unless caller;
 
 BEGIN {
 my $cwd = cwd();
@@ -47,6 +45,8 @@ my %Defaults = (
 	worker_class          => 'MyCPAN::Indexer::Worker',
 	reporter_class        => 'MyCPAN::Indexer::Reporter::AsYAML',
 	parallel_jobs         => 1,
+	organize_dists        => 0,
+	pause_id              => 'MYCPAN',
 	);
 
 sub default { $Defaults{$_[1]} }
@@ -74,18 +74,18 @@ sub get_config
 sub adjust_config
 	{
 	my( $self, $Config, @argv ) = @_;
-	
+
 	# set the directories to index
 	unless( $Config->exists( 'backpan_dir') )
 		{
 		$Config->set( 'backpan_dir', [ @argv ? @argv : cwd() ] );
 		}
-	
+
 	unless( ref $Config->get( 'backpan_dir' ) eq ref [] )
 		{
 		$Config->set( 'backpan_dir', [ $Config->get( 'backpan_dir' ) ] );
 		}
-		
+
 	if( $Config->exists( 'report_dir' ) )
 		{
 		foreach my $subdir ( qw(success error) )
@@ -95,14 +95,15 @@ sub adjust_config
 				catfile( $Config->get( 'report_dir' ), $subdir ),
 				);
 			}
-		}		
-			
+		}
+
 	}
-	
-sub run
+
+sub activate
 	{
 	my( $self, @argv ) = @_;
 	use vars qw( %Options );
+	local %ENV = %ENV;
 
 	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 	# Process the options
@@ -121,20 +122,20 @@ sub run
 	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 	# Minutely control the environment
 	$self->setup_environment;
-	
+
 	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 	# Adjust config based on run parameters
 	my $Config = $self->get_config( $Options{f} );
 
 	$self->adjust_config( $Config, @argv );
-	
+
 	if( $Options{c} )
 		{
 		use Data::Dumper;
 		print STDERR Dumper( $Config );
 		exit;
 		}
-	
+
 	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 	# Load classes and check that they do the right thing
 	my $Notes = {
@@ -143,7 +144,7 @@ sub run
 		tempdirs   => [],
 		log_file   => $Options{l},
 		};
-
+	
 	$self->setup_logging( $Notes );
 
 	$self->setup_dirs( $Notes );
@@ -167,8 +168,10 @@ sub run
 		}
 
 	}
-	
-	$self->cleanup_and_exit( $Notes );
+
+	$self->cleanup( $Notes );
+
+	$self->_exit( $Notes );
 	}
 
 sub setup_environment
@@ -182,15 +185,15 @@ sub setup_environment
 
 	$ENV{AUTOMATED_TESTING}++;
 	}
-	
+
 sub setup_logging
 	{
 	my( $self, $Notes ) = @_;
-	
+
 	if( -e $Notes->{log_file} )
 		{
-		Log::Log4perl->init_and_watch( 
-			$Notes->{log_file}, 
+		Log::Log4perl->init_and_watch(
+			$Notes->{log_file},
 			$Notes->{config}->get( 'log_file_watch_time' )
 			);
 		}
@@ -199,7 +202,7 @@ sub setup_logging
 		Log::Log4perl->easy_init( $Log::Log4perl::ERROR );
 		}
 	}
-	
+
 sub components
 	{
 	(
@@ -212,34 +215,43 @@ sub components
 	)
 	}
 
-sub cleanup_and_exit
+sub cleanup
 	{
 	my( $self, $Notes ) = @_;
-	
+
 	require File::Path;
-	
+
 	my @dirs = @{ $Notes->{tempdirs} }, $Notes->{config}->get('temp_dir');
 	$logger->debug( "Dirs to remove are @dirs" );
-	
+
 	eval {
 		no warnings;
 		File::Path::rmtree [@dirs];
 		};
-	
+
 	print STDERR "$@\n" if $@;
+
+	$logger->error( "Couldn't cleanup: $@" ) if $@;
+	}
+
+# I'm don't remember why I made an explicit exit. Was it to get
+# out of a Tk app or something?
+sub _exit
+	{
+	my( $self, $Notes ) = @_;
 	
-	$logger->error( "Couldn't cleanup before exiting: $@" ) if $@;
-	
+	$logger->info( "Exiting from ", __PACKAGE__ );
+		
 	exit 0;
 	}
-	
+
 sub setup_dirs # XXX big ugly mess to clean up
 	{
 	my( $self, $Notes ) = @_;
 
 	my $Config = $Notes->{config};
-	
-# Okay, I've gone back and forth on this a couple of times. There is 
+
+# Okay, I've gone back and forth on this a couple of times. There is
 # no default for temp_dir. I create it here so it's only set when I
 # need it. It either comes from the user or on-demand creation. I then
 # set it's value in the configuration.
@@ -255,7 +267,7 @@ sub setup_dirs # XXX big ugly mess to clean up
 	foreach my $key ( qw(report_dir success_report_subdir error_report_subdir) )
 		{
 		my $dir = $Config->get( $key );
-		
+
 		mkpath( $dir ) unless -d $dir;
 		$logger->logdie( "$key [$dir] does not exist!" ) unless -d $dir;
 		}
